@@ -672,55 +672,3 @@ QImage kpPixmapFX::rotate (const QImage &pm, double angle,
 }
 
 //---------------------------------------------------------------------
-
-
-// public static
-QMatrix kpPixmapFX::flipMatrix (int width, int height, bool horz, bool vert)
-{
-    if (width <= 0 || height <= 0)
-    {
-        kError () << "kpPixmapFX::flipMatrix() passed invalid dimensions" << endl;
-        return QMatrix ();
-    }
-
-    QMatrix matrix (horz ? -1 : +1,  // m11
-                     0,  // m12
-                     0,  // m21
-                     vert ? -1 : +1,  // m22
-                     horz ? (width - 1) : 0,  // dx
-                     vert ? (height - 1) : 0);  // dy
-    return matrix;
-}
-
-//---------------------------------------------------------------------
-
-// public static
-QMatrix kpPixmapFX::flipMatrix (const QImage &pixmap, bool horz, bool vert)
-{
-    return kpPixmapFX::flipMatrix (pixmap.width (), pixmap.height (),
-                                   horz, vert);
-}
-
-//---------------------------------------------------------------------
-
-// public static
-void kpPixmapFX::flip (QImage *destPtr, bool horz, bool vert)
-{
-    if (!horz && !vert)
-        return;
-
-    *destPtr = kpPixmapFX::flip (*destPtr, horz, vert);
-}
-
-//---------------------------------------------------------------------
-
-// public static
-QImage kpPixmapFX::flip (const QImage &img, bool horz, bool vert)
-{
-    if (!horz && !vert)
-        return img;
-
-    return img.mirrored (horz, vert);
-}
-
-//---------------------------------------------------------------------
